==> tidalcycles-1.4.2-4-x86_64.pkg.tar.xz: usr/share/haskell/register/tidalcycles.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tidal
version: 1.4.2
id: tidal-1.4.2-LgOmlT2eJ44DDavdLPoQOx
key: tidal-1.4.2-LgOmlT2eJ44DDavdLPoQOx
license: GPL-3.0-only
copyright: (c) Tidal contributors, 2019
maintainer: Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>
author: Alex McLean
stability: Experimental
homepage: http://tidalcycles.org/
synopsis: Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.
category: Sound
abi: 1c882df119449597d8b538b8fb7db535
exposed: True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.Tempo
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version
import-dirs: /usr/lib/ghc-8.6.5/site-local/tidal-1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tidal-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tidal-1.4.2
hs-libraries: HStidal-1.4.2-LgOmlT2eJ44DDavdLPoQOx
depends:
    base-4.12.0.0 bifunctors-5.5.5-H6ZQWPR6nusfP0g8Bh48f
    bytestring-0.10.8.2 clock-0.8-H1S1zDefxirImaRbI6ITNv
    colour-2.3.5-y0xjV3ONUd40VuBtReEvC containers-0.6.0.1
    deepseq-1.4.4.0 hosc-0.17-BPnPLwXx6SmJGv8Spv6X5G
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    network-2.8.0.0-1DkaUVvVIsp8sj7KmlE9xl parsec-3.1.13.0
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/tidalcycles/html/tidal.haddock
haddock-html: /usr/share/doc/tidalcycles/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> tidalcycles-1.4.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/tidalcycles.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tidal
version: 1.4.2
id: tidal-1.4.2-Fu0l68TMhhh9NoURqL0FJT
key: tidal-1.4.2-Fu0l68TMhhh9NoURqL0FJT
license: GPL-3.0-only
copyright: (c) Tidal contributors, 2019
maintainer: Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>
author: Alex McLean
stability: Experimental
homepage: http://tidalcycles.org/
synopsis: Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.
category: Sound
abi: 92708c234bfbedb4f272f10d520e1712
exposed: True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.Tempo
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version
import-dirs: /usr/lib/ghc-8.6.5/site-local/tidal-1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tidal-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tidal-1.4.2
hs-libraries: HStidal-1.4.2-Fu0l68TMhhh9NoURqL0FJT
depends:
    base-4.12.0.0 bifunctors-5.5.5-AT2O4t2mUeVLY6LKXIjARE
    bytestring-0.10.8.2 clock-0.8-H1S1zDefxirImaRbI6ITNv
    colour-2.3.5-y0xjV3ONUd40VuBtReEvC containers-0.6.0.1
    deepseq-1.4.4.0 hosc-0.17-BhQbl46ij8gDYR9tHzj2BV
    mwc-random-0.14.0.0-2pxNHDgDQNDAJj9EQzqdx2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R parsec-3.1.13.0
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b text-1.2.3.1
    transformers-0.5.6.2 vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/tidalcycles/html/tidal.haddock
haddock-html: /usr/share/doc/tidalcycles/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
